pub enum MetaMethod {
Show 23 variants
Add,
Sub,
Mul,
Div,
Mod,
Pow,
Unm,
IDiv,
BAnd,
BOr,
BXor,
BNot,
Shl,
Shr,
Concat,
Len,
Eq,
Lt,
Le,
Index,
NewIndex,
Call,
ToString,
}Expand description
Kinds of metamethods that can be overridden.
Currently, this mechanism does not allow overriding the __gc metamethod, since there is
generally no need to do so: UserData implementors can instead just implement Drop.
Variants
Add
The + operator.
Sub
The - operator.
Mul
The * operator.
Div
The / operator.
Mod
The % operator.
Pow
The ^ operator.
Unm
The unary minus (-) operator.
IDiv
The floor division (//) operator.
BAnd
The bitwise AND (&) operator.
BOr
The bitwise OR (|) operator.
BXor
The bitwise XOR (binary ~) operator.
BNot
The bitwise NOT (unary ~) operator.
Shl
The bitwise left shift (<<) operator.
Shr
The bitwise right shift (>>) operator.
Concat
The string concatenation operator ...
Len
The length operator #.
Eq
The == operator.
Lt
The < operator.
Le
The <= operator.
Index
Index access obj[key].
NewIndex
Index write access obj[key] = value.
Call
The call “operator” obj(arg1, args2, ...).
ToString
The __tostring metamethod.
This is not an operator, but will be called by methods such as tostring and print.